============
Installation
============


If you are using `Anaconda`_ or Miniconda, install Intake-stac with the following commands::

    conda install -c conda-forge intake-stac

If you are using virtualenv/pip, run the following command::

    pip install intake-stac

.. _Anaconda: https://www.anaconda.com/download/
